## DDD for Python

DDD for Python is a framework for developing software systems based on the principles outlined in Domain-Driven Design by Eric Evans.

### Credits:

Credits goes to Eric Evans for his work on coining the term "Domain-Driven Design" and outlining the theory in his book with the same title.

The design of this framework was also inspired by the works of Vaughn Vernon on implementing domain-driven design.

Some inspiration of for this framework also comes from the web framework Django.

### Theory:

To learn DDD, the following sources are highly recommended:

- [Domain-Driven Design: Tackling Complexity in the Heart of Software (Eric Evans)](https://www.amazon.com/Domain-Driven-Design-Tackling-Complexity-Software/dp/0321125215)
- [Implementing Domain-Driven Design - Vaughn Vernon](https://www.amazon.com/Implementing-Domain-Driven-Design-Vaughn-Vernon/dp/0321834577)

### Installation:

```bash
$ pip install ddd-for-python
```

### Examples:

The examples are coming shortly.

### Documentation:

The documentation is coming shortly. Meanwhile, you can check out the example code in this repository.

### Change Log:


| | | |
|-|-|-|
| __Date__   | __Version__ | __Changes__                                                              |
| 2021-03-14 | 0.9.0       | Initial release.                                                         |
